.. _mysql_module:

:mod:`fabtools.mysql`
---------------------

.. automodule:: fabtools.mysql

    .. seealso:: :ref:`require_mysql_module`

    Queries
    ~~~~~~~

    .. autofunction:: query

    Manage users
    ~~~~~~~~~~~~

    .. autofunction:: user_exists
    .. autofunction:: create_user

    Manage databases
    ~~~~~~~~~~~~~~~~

    .. autofunction:: database_exists
    .. autofunction:: create_database
